@@ -15,7 +15,7 @@ import math
 import numpy as np
 
 class ForecasterParalleLauncher():
-    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None,frequence=None,selected_algo=None,db_path_suffix = '_forecaster.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None, frequence=None, db_path_suffix = '_forecaster.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
         self.starting_date = starting_date
         self.running_date = running_date
         self.args = []
@@ -52,7 +52,7 @@ class ForecasterParalleLauncher():
         self.user = user
 
         self.db_path_suffix = db_path_suffix
-        self.filename =  launcher_utility.get_database_name(user, frequence, underlying, selected_algo, starting_date, running_date, db_path_suffix)
+        self.filename =  launcher_utility.get_database_name(user, frequence, underlying, 'default', starting_date, running_date, db_path_suffix)
         self.db_path = self.local_root_directory + self.filename
         self.runs = []
         self.totalRow = 0
